[monkey-bubble: 672/753] Make gnome-app and friends compile and all that good stuff. Not finished,
- From: Sven Herzberg <herzi src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [monkey-bubble: 672/753] Make gnome-app and friends compile and all that good stuff. Not finished,
- Date: Wed, 14 Jul 2010 22:52:11 +0000 (UTC)
commit 8cbc2dd8635b967b7763fdbd1d1ad6f615e64883
Author: George Lebl <jirka 5z com>
Date: Mon Aug 27 02:35:22 2001 +0000
Make gnome-app and friends compile and all that good stuff. Not finished,
Sun Aug 26 19:35:04 2001 George Lebl <jirka 5z com>
* Makefile.am, gnome-app-helper.[ch], gnome-app-util.[ch],
gnome-app.[ch], libgnomeui.h: Make gnome-app and friends
compile and all that good stuff. Not finished, but somewhat
there. gnome-app-util is deprecated here.
libgnomeui/ChangeLog | 7 ++
libgnomeui/Makefile.am | 8 ++
libgnomeui/gnome-app-helper.c | 156 ++++++++++++++++++++++-------------------
libgnomeui/gnome-app-helper.h | 2 +-
libgnomeui/gnome-app-util.c | 122 +++++---------------------------
libgnomeui/gnome-app-util.h | 6 +-
libgnomeui/gnome-app.c | 129 ++++++++++++++++++----------------
libgnomeui/gnome-app.h | 21 +++---
libgnomeui/libgnomeui.h | 9 +++
9 files changed, 207 insertions(+), 253 deletions(-)
---
diff --git a/libgnomeui/ChangeLog b/libgnomeui/ChangeLog
index ae80202..5fa46d6 100644
--- a/libgnomeui/ChangeLog
+++ b/libgnomeui/ChangeLog
@@ -1,3 +1,10 @@
+Sun Aug 26 19:35:04 2001 George Lebl <jirka 5z com>
+
+ * Makefile.am, gnome-app-helper.[ch], gnome-app-util.[ch],
+ gnome-app.[ch], libgnomeui.h: Make gnome-app and friends
+ compile and all that good stuff. Not finished, but somewhat
+ there. gnome-app-util is deprecated here.
+
Sun Aug 26 16:37:35 2001 George Lebl <jirka 5z com>
* gnome-i18nP.h, gnome-app-util.c, gnome-app.c, gnome-canvas-init.c,
diff --git a/libgnomeui/Makefile.am b/libgnomeui/Makefile.am
index c6d7232..bbdf71d 100644
--- a/libgnomeui/Makefile.am
+++ b/libgnomeui/Makefile.am
@@ -44,6 +44,10 @@ noinst_HEADERS = \
libgnomeui_2_la_SOURCES = \
gnometypebuiltins.h \
gnometypebuiltins.c \
+ gnome-app.c \
+ gnome-app-helper.c \
+ gnome-app-util.c \
+ gnome-appbar.c \
gnome-stock-icons.c \
gnome-canvas-init.c \
gnome-client.c \
@@ -74,6 +78,10 @@ libgnomeui_2_la_SOURCES = \
## this lists all the non-generated headers
gnome_headers = \
+ gnome-app.h \
+ gnome-app-helper.h \
+ gnome-app-util.h \
+ gnome-appbar.h \
gnome-canvas-init.h \
gnome-client.h \
gnome-color-picker.h \
diff --git a/libgnomeui/gnome-app-helper.c b/libgnomeui/gnome-app-helper.c
index ea9794a..db6ef23 100644
--- a/libgnomeui/gnome-app-helper.c
+++ b/libgnomeui/gnome-app-helper.c
@@ -39,14 +39,14 @@
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
+#include <gconf/gconf.h>
+#include <gconf/gconf-client.h>
#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>
#include <libgnome/libgnome.h>
#include <libgnome/gnome-util.h>
#include <libgnome/gnome-config.h>
-#include "gnome-helpsys.h"
-#include "gnome-gconf.h"
/* Note that this file must include gnome-i18n, and not gnome-i18nP, so that
* _() is the same as the one seen by the application. This is moderately
@@ -57,12 +57,8 @@
#include "gnome-app.h"
#include "gnome-app-helper.h"
#include "gnome-uidefs.h"
-#include "gnome-stock.h"
-#include "gnome-pixmap.h"
+#include "gnome-stock-icons.h"
#include <libgnome/gnome-preferences.h>
-#include "gnome-stock.h"
-
-extern const gchar *gnome_user_accels_dir;
/* keys used for get/set_data */
const char *gnome_app_helper_gconf_client = "gnome-app-helper-gconf-client";
@@ -104,50 +100,50 @@ static GnomeUIInfo menu_defaults[] = {
/* New */
{ GNOME_APP_UI_ITEM, NULL, NULL,
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_NEW,
GNOME_KEY_NAME_NEW, GNOME_KEY_MOD_NEW, NULL },
/* Open */
{ GNOME_APP_UI_ITEM, N_("_Open..."), N_("Open a file"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
GNOME_KEY_NAME_OPEN, GNOME_KEY_MOD_OPEN, NULL },
/* Save */
{ GNOME_APP_UI_ITEM, N_("_Save"), N_("Save the current file"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_SAVE,
GNOME_KEY_NAME_SAVE, GNOME_KEY_MOD_SAVE, NULL },
/* Save As */
{ GNOME_APP_UI_ITEM, N_("Save _As..."),
N_("Save the current file with a different name"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_SAVE_AS,
GNOME_KEY_NAME_SAVE_AS, GNOME_KEY_MOD_SAVE_AS, NULL },
/* Revert */
{ GNOME_APP_UI_ITEM, N_("_Revert"),
N_("Revert to a saved version of the file"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REVERT,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REVERT_TO_SAVED,
0, (GdkModifierType) 0, NULL },
/* Print */
{ GNOME_APP_UI_ITEM, N_("_Print"), N_("Print the current file"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PRINT,
GNOME_KEY_NAME_PRINT, GNOME_KEY_MOD_PRINT, NULL },
/* Print Setup */
{ GNOME_APP_UI_ITEM, N_("Print S_etup..."),
N_("Setup the page settings for your current printer"),
NULL, NULL,
- NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT,
+ NULL, GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PRINT,
GNOME_KEY_NAME_PRINT_SETUP, GNOME_KEY_MOD_PRINT_SETUP, NULL },
/* Close */
{ GNOME_APP_UI_ITEM, N_("_Close"), N_("Close the current file"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CLOSE,
GNOME_KEY_NAME_CLOSE, GNOME_KEY_MOD_CLOSE, NULL },
/* Exit */
{ GNOME_APP_UI_ITEM, N_("E_xit"), N_("Exit the program"),
NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
- GNOME_STOCK_MENU_EXIT, GNOME_KEY_NAME_EXIT, GNOME_KEY_MOD_EXIT,
+ GTK_STOCK_QUIT, GNOME_KEY_NAME_EXIT, GNOME_KEY_MOD_EXIT,
NULL },
/*
* The "Edit" menu
@@ -155,55 +151,55 @@ static GnomeUIInfo menu_defaults[] = {
/* Cut */
{ GNOME_APP_UI_ITEM, N_("C_ut"), N_("Cut the selection"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CUT,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CUT,
GNOME_KEY_NAME_CUT, GNOME_KEY_MOD_CUT, NULL },
/* 10 */
/* Copy */
{ GNOME_APP_UI_ITEM, N_("_Copy"), N_("Copy the selection"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_COPY,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_COPY,
GNOME_KEY_NAME_COPY, GNOME_KEY_MOD_COPY, NULL },
/* Paste */
{ GNOME_APP_UI_ITEM, N_("_Paste"), N_("Paste the clipboard"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PASTE,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PASTE,
GNOME_KEY_NAME_PASTE, GNOME_KEY_MOD_PASTE, NULL },
/* Clear */
{ GNOME_APP_UI_ITEM, N_("C_lear"), N_("Clear the selection"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_NONE, NULL,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CLEAR,
GNOME_KEY_NAME_CLEAR, GNOME_KEY_MOD_CLEAR, NULL },
/* Undo */
{ GNOME_APP_UI_ITEM, N_("_Undo"), N_("Undo the last action"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_UNDO,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO,
GNOME_KEY_NAME_UNDO, GNOME_KEY_MOD_UNDO, NULL },
/* Redo */
{ GNOME_APP_UI_ITEM, N_("_Redo"), N_("Redo the undone action"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REDO,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REDO,
GNOME_KEY_NAME_REDO, GNOME_KEY_MOD_REDO, NULL },
/* Find */
{ GNOME_APP_UI_ITEM, N_("_Find..."), N_("Search for a string"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
GNOME_KEY_NAME_FIND, GNOME_KEY_MOD_FIND, NULL },
/* Find Again */
{ GNOME_APP_UI_ITEM, N_("Find _Again"),
N_("Search again for the same string"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
GNOME_KEY_NAME_FIND_AGAIN, GNOME_KEY_MOD_FIND_AGAIN, NULL },
/* Replace */
{ GNOME_APP_UI_ITEM, N_("_Replace..."), N_("Replace a string"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SRCHRPL,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND_AND_REPLACE,
GNOME_KEY_NAME_REPLACE, GNOME_KEY_MOD_REPLACE, NULL },
/* Properties */
{ GNOME_APP_UI_ITEM, N_("_Properties..."),
N_("Modify the file's properties"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
0, (GdkModifierType) 0, NULL },
/*
* The Settings menu
@@ -212,7 +208,7 @@ static GnomeUIInfo menu_defaults[] = {
{ GNOME_APP_UI_ITEM, N_("_Preferences..."),
N_("Configure the application"),
NULL, NULL,
- NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
+ NULL, GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PREFERENCES,
0, (GdkModifierType) 0, NULL },
/* 20 */
/*
@@ -221,7 +217,7 @@ static GnomeUIInfo menu_defaults[] = {
/* About */
{ GNOME_APP_UI_ITEM, N_("_About"),
N_("About this application"), NULL, NULL,
- NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
+ NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_ABOUT,
0, (GdkModifierType) 0, NULL },
{ GNOME_APP_UI_ITEM, N_("_Select All"),
N_("Select everything"),
@@ -254,7 +250,7 @@ static GnomeUIInfo menu_defaults[] = {
{ GNOME_APP_UI_ITEM, N_("_Pause game"),
N_("Pause the game"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TIMER_STOP,
+ GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_TIMER_STOP,
GNOME_KEY_NAME_PAUSE_GAME, GNOME_KEY_MOD_PAUSE_GAME, NULL },
{ GNOME_APP_UI_ITEM, N_("_Restart game"),
N_("Restart the game"),
@@ -264,12 +260,12 @@ static GnomeUIInfo menu_defaults[] = {
{ GNOME_APP_UI_ITEM, N_("_Undo move"),
N_("Undo the last move"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_UNDO,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO,
GNOME_KEY_NAME_UNDO_MOVE, GNOME_KEY_MOD_UNDO_MOVE, NULL },
{ GNOME_APP_UI_ITEM, N_("_Redo move"),
N_("Redo the undone move"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REDO,
+ GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REDO,
GNOME_KEY_NAME_REDO_MOVE, GNOME_KEY_MOD_REDO_MOVE, NULL },
{ GNOME_APP_UI_ITEM, N_("_Hint"),
N_("Get a hint for your next move"),
@@ -280,7 +276,7 @@ static GnomeUIInfo menu_defaults[] = {
{ GNOME_APP_UI_ITEM, N_("_Scores..."),
N_("View the scores"),
NULL, NULL, NULL,
- GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SCORES,
+ GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_SCORES,
0, (GdkModifierType) 0, NULL },
{ GNOME_APP_UI_ITEM, N_("_End game"),
N_("End the current game"),
@@ -333,7 +329,8 @@ static gchar *menu_names[] =
/* Creates a pixmap appropriate for items. */
static GtkWidget *
-create_pixmap (GnomeUIPixmapType pixmap_type, gconstpointer pixmap_info)
+create_pixmap (GnomeUIPixmapType pixmap_type, gconstpointer pixmap_info,
+ GtkIconSize icon_size)
{
GtkWidget *pixmap;
char *name;
@@ -341,15 +338,20 @@ create_pixmap (GnomeUIPixmapType pixmap_type, gconstpointer pixmap_info)
pixmap = NULL;
switch (pixmap_type) {
-#ifdef FIXME
case GNOME_APP_PIXMAP_STOCK:
- pixmap = gnome_stock_new_with_icon (pixmap_info);
+ pixmap = gtk_image_new_from_stock (pixmap_info,
+ icon_size);
break;
-#endif
case GNOME_APP_PIXMAP_DATA:
- if (pixmap_info)
- pixmap = gnome_pixmap_new_from_xpm_d ((const char**)pixmap_info);
+ if (pixmap_info != NULL) {
+ GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data
+ ((const char **)pixmap_info);
+ if (pixbuf != NULL) {
+ pixmap = gtk_image_new_from_pixbuf (pixbuf);
+ gdk_pixbuf_unref (pixbuf);
+ }
+ }
break;
@@ -365,7 +367,7 @@ create_pixmap (GnomeUIPixmapType pixmap_type, gconstpointer pixmap_info)
g_warning ("Could not find GNOME pixmap file %s",
(char *) pixmap_info);
else {
- pixmap = gnome_pixmap_new_from_file (name);
+ pixmap = gtk_image_new_from_file (name);
g_free (name);
}
@@ -406,13 +408,17 @@ showing_pixmaps_changed_notify(GConfClient *client,
pixmap_info = gtk_object_get_data(GTK_OBJECT(mi),
gnome_app_helper_pixmap_info);
- pixmap = create_pixmap(pixmap_type, pixmap_info);
+ pixmap = create_pixmap (pixmap_type, pixmap_info,
+ GTK_ICON_SIZE_MENU);
- gtk_widget_show(pixmap);
-
- g_object_set(G_OBJECT(mi), "image", pixmap, NULL);
+ if (pixmap != NULL) {
+ gtk_widget_show(pixmap);
+
+ gtk_image_menu_item_set_image
+ (GTK_IMAGE_MENU_ITEM (mi), pixmap);
+ }
} else if (!new_setting && (mi->image != NULL)) {
- g_object_set(G_OBJECT(mi), "image", NULL, NULL);
+ gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), NULL);
}
}
@@ -432,8 +438,8 @@ remove_notify_cb(GtkObject *obj, gpointer data)
}
static void
-setup_image_menu_item(GtkWidget *mi, GnomeUIPixmapType pixmap_type,
- gconstpointer pixmap_info)
+setup_image_menu_item (GtkWidget *mi, GnomeUIPixmapType pixmap_type,
+ gconstpointer pixmap_info)
{
guint notify_id;
GConfClient *conf;
@@ -458,11 +464,14 @@ setup_image_menu_item(GtkWidget *mi, GnomeUIPixmapType pixmap_type,
NULL)) {
GtkWidget *pixmap;
- pixmap = create_pixmap(pixmap_type, pixmap_info);
+ pixmap = create_pixmap (pixmap_type, pixmap_info,
+ GTK_ICON_SIZE_MENU);
- gtk_widget_show(pixmap);
-
- g_object_set(G_OBJECT(mi), "image", pixmap, NULL);
+ if (pixmap != NULL) {
+ gtk_widget_show (pixmap);
+ gtk_image_menu_item_set_image
+ (GTK_IMAGE_MENU_ITEM (mi), pixmap);
+ }
}
notify_id = gconf_client_notify_add(conf,
@@ -963,7 +972,7 @@ create_menu_item (GtkMenuShell *menu_shell,
switch (uiinfo->type) {
case GNOME_APP_UI_SEPARATOR:
- uiinfo->widget = gtk_menu_item_new ();
+ uiinfo->widget = gtk_separator_menu_item_new ();
break;
case GNOME_APP_UI_ITEM:
case GNOME_APP_UI_SUBTREE:
@@ -976,20 +985,13 @@ create_menu_item (GtkMenuShell *menu_shell,
/* Create the pixmap */
- /* FIXME: this should later allow for on-the-fly configuration of
- * whether pixmaps are displayed or not ???
- */
-
- if ((uiinfo->pixmap_type != GNOME_APP_PIXMAP_NONE) &&
- gnome_preferences_get_menus_have_icons()) {
- uiinfo->widget = gtk_image_menu_item_new (NULL,
- uiinfo->label ? uiinfo->label : "");
+ uiinfo->widget = gtk_image_menu_item_new ();
- setup_image_menu_item(uiinfo->widget,
- uiinfo->pixmap_type,
- uiinfo->pixmap_info);
- } else
- uiinfo->widget = gtk_menu_item_new ();
+ if (uiinfo->pixmap_type != GNOME_APP_PIXMAP_NONE) {
+ setup_image_menu_item (uiinfo->widget,
+ uiinfo->pixmap_type,
+ uiinfo->pixmap_info);
+ }
}
break;
@@ -1396,6 +1398,8 @@ gnome_app_fill_menu_custom (GtkMenuShell *menu_shell,
(GTK_MENU_SHELL (menu),
uiinfo->moreinfo, orig_uibdata,
accel_group, uline_accels, 0);
+
+ /* FIXME: make this runtime configurable */
if (gnome_preferences_get_menus_have_tearoff ()) {
tearoff = gtk_tearoff_menu_item_new ();
gtk_widget_show (tearoff);
@@ -1589,6 +1593,7 @@ gnome_app_create_menus_custom (GnomeApp *app, GnomeUIInfo *uiinfo,
gnome_app_fill_menu_custom (GTK_MENU_SHELL (menubar), uiinfo, uibdata,
app->accel_group, TRUE, 0);
+ /* FIXME: make this runtime configurable */
if (gnome_preferences_get_menus_have_tearoff ()) {
gchar *app_name;
@@ -1622,7 +1627,9 @@ create_toolbar_item (GtkToolbar *toolbar, GnomeUIInfo *uiinfo, int is_radio,
case GNOME_APP_UI_TOGGLEITEM:
/* Create the icon */
- pixmap = create_pixmap (uiinfo->pixmap_type, uiinfo->pixmap_info);
+ pixmap = create_pixmap (uiinfo->pixmap_type, uiinfo->pixmap_info,
+ /* FIXME: what about small toolbar */
+ GTK_ICON_SIZE_LARGE_TOOLBAR);
/* Create the toolbar item */
@@ -1929,7 +1936,12 @@ gnome_app_create_toolbar_custom (GnomeApp *app, GnomeUIInfo *uiinfo, GnomeUIBuil
g_return_if_fail (uiinfo != NULL);
g_return_if_fail (uibdata != NULL);
- toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH);
+ toolbar = gtk_toolbar_new ();
+ gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
+ GTK_ORIENTATION_HORIZONTAL);
+ /* FIXME: isn't this set by some of that gtk+2->gconf magic goo? */
+ gtk_toolbar_set_style (GTK_TOOLBAR (toolbar),
+ GTK_TOOLBAR_BOTH);
gnome_app_fill_toolbar_custom(GTK_TOOLBAR (toolbar), uiinfo, uibdata,
app->accel_group);
gnome_app_set_toolbar (app, GTK_TOOLBAR (toolbar));
@@ -2325,15 +2337,15 @@ gnome_app_helper_gettext (const gchar *str)
#endif
static void
-set_bevels(GnomeDockItem *dock_item, gboolean bevels)
+set_bevels(BonoboDockItem *dock_item, gboolean bevels)
{
if (bevels) {
gtk_container_set_border_width (GTK_CONTAINER (dock_item), 1);
- gnome_dock_item_set_shadow_type (GNOME_DOCK_ITEM (dock_item),
+ bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
GTK_SHADOW_OUT);
} else {
gtk_container_set_border_width (GTK_CONTAINER (dock_item), 0);
- gnome_dock_item_set_shadow_type (GNOME_DOCK_ITEM (dock_item),
+ bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
GTK_SHADOW_NONE);
}
}
@@ -2346,7 +2358,7 @@ dockitem_bevels_changed_notify(GConfClient *client,
{
gboolean bevels = TRUE;
GtkWidget *w = user_data;
- GnomeDockItem *dock_item = GNOME_DOCK_ITEM(w);
+ BonoboDockItem *dock_item = BONOBO_DOCK_ITEM(w);
GConfValue *value = gconf_entry_get_value (entry);
if (value &&
@@ -2518,7 +2530,7 @@ toolbar_style_changed_notify(GConfClient *client,
/**
* gnome_app_setup_toolbar
* @toolbar: Pointer to #GtkToolbar widget
- * @dock_item: Pointer to a #GnomeDockItem the toolbar is inside, or NULL for none
+ * @dock_item: Pointer to a #BonoboDockItem the toolbar is inside, or NULL for none
*
* Description:
* Sets up a toolbar to use GNOME user preferences
@@ -2526,7 +2538,7 @@ toolbar_style_changed_notify(GConfClient *client,
void
gnome_app_setup_toolbar (GtkToolbar *toolbar,
- GnomeDockItem *dock_item)
+ BonoboDockItem *dock_item)
{
GConfClient *conf;
diff --git a/libgnomeui/gnome-app-helper.h b/libgnomeui/gnome-app-helper.h
index 227ad9a..185f896 100644
--- a/libgnomeui/gnome-app-helper.h
+++ b/libgnomeui/gnome-app-helper.h
@@ -735,7 +735,7 @@ void gnome_app_install_menu_hints (GnomeApp *app,
GnomeUIInfo *uinfo);
void gnome_app_setup_toolbar (GtkToolbar *toolbar,
- GnomeDockItem *dock_item);
+ BonoboDockItem *dock_item);
G_END_DECLS
diff --git a/libgnomeui/gnome-app-util.c b/libgnomeui/gnome-app-util.c
index 668e488..13b30b9 100644
--- a/libgnomeui/gnome-app-util.c
+++ b/libgnomeui/gnome-app-util.c
@@ -24,19 +24,18 @@
*/
#include <config.h>
-#include "gnome-app-util.h"
+#ifndef GNOME_DISABLE_DEPRECATED_SOURCE
/* Must be before all other gnome includes!! */
#include "gnome-i18nP.h"
-#include <libgnome/gnome-i18n.h>
#include <libgnome/gnome-util.h>
-#include "gnome-stock.h"
+#include "gnome-app-util.h"
+
#include "gnome-dialog-util.h"
#include "gnome-dialog.h"
#include "gnome-uidefs.h"
-#include "gnome-preferences.h"
#include "gnome-appbar.h"
#include <gdk/gdkx.h>
@@ -59,9 +58,10 @@ gnome_app_has_appbar_status(GnomeApp * app)
static gboolean
gnome_app_interactive_statusbar(GnomeApp * app)
{
- return ( gnome_app_has_appbar_status (app) &&
- gnome_preferences_get_statusbar_dialog() &&
- gnome_preferences_get_statusbar_interactive() );
+ return ( gnome_app_has_appbar_status (app) && 0
+ /* FIXME!!!
+ && gnome_preferences_get_statusbar_dialog()
+ && gnome_preferences_get_statusbar_interactive() */);
}
static void gnome_app_activate_statusbar(GnomeApp *app)
@@ -130,8 +130,9 @@ gnome_app_message (GnomeApp * app, const gchar * message)
g_return_val_if_fail(app != NULL, NULL);
g_return_val_if_fail(GNOME_IS_APP(app), NULL);
- if ( gnome_preferences_get_statusbar_dialog() &&
- gnome_app_interactive_statusbar(app) ) {
+ /* FIXME !!! */
+ if ( 0 /*gnome_preferences_get_statusbar_dialog() &&
+ gnome_app_interactive_statusbar(app) */) {
gnome_app_message_bar ( app, message );
return NULL;
}
@@ -207,8 +208,9 @@ gnome_app_warning (GnomeApp * app, const gchar * warning)
g_return_val_if_fail(GNOME_IS_APP(app), NULL);
g_return_val_if_fail(warning != NULL, NULL);
- if ( gnome_app_has_appbar_status(app) &&
- gnome_preferences_get_statusbar_dialog() ) {
+ /* FIXME !!! */
+ if ( 0 /*gnome_app_has_appbar_status(app) &&
+ gnome_preferences_get_statusbar_dialog() */) {
gnome_app_warning_bar(app, warning);
return NULL;
}
@@ -771,7 +773,8 @@ gnome_app_progress_timeout (GnomeApp * app,
key->data = data;
if ( gnome_app_has_appbar_progress(app) &&
- gnome_preferences_get_statusbar_dialog() ) {
+ /* FIXME !!! */
+ 0 /* gnome_preferences_get_statusbar_dialog() */) {
progress_bar (description, key);
}
else {
@@ -823,7 +826,8 @@ gnome_app_progress_manual (GnomeApp * app,
key->timeout_tag = INVALID_TIMEOUT;
if ( gnome_app_has_appbar_progress(app) &&
- gnome_preferences_get_statusbar_dialog() ) {
+ /* FIXME !!! */
+ 0 /*gnome_preferences_get_statusbar_dialog() */) {
progress_bar (description, key);
}
else {
@@ -895,94 +899,4 @@ void gnome_app_progress_done (GnomeAppProgressKey key)
g_free(key);
}
-typedef struct {
- GdkPixmap *icon_pixmap;
- GdkBitmap *icon_mask;
- GdkWindow *icon_window;
-} IconInfo;
-
-static void
-gnome_window_realized(GtkWindow *window, IconInfo *pbi)
-{
- gdk_window_set_icon(GTK_WIDGET(window)->window, pbi->icon_window, pbi->icon_pixmap, pbi->icon_mask);
-}
-
-static void
-gnome_window_destroyed(GtkWindow *window, IconInfo *pbi)
-{
- gdk_pixmap_unref(pbi->icon_pixmap);
- gdk_bitmap_unref(pbi->icon_mask);
- gdk_window_unref(pbi->icon_window);
- g_free(pbi);
-}
-
-void
-gnome_window_set_icon(GtkWindow *window, GdkPixbuf *pixbuf, gboolean overwrite)
-{
- gboolean skip_connect = FALSE;
- IconInfo *pbi;
-
- pbi = gtk_object_get_data(GTK_OBJECT(window), "WM_HINTS.icon_info");
- if(pbi && !overwrite)
- return;
- if(pbi)
- {
- skip_connect = TRUE;
- gdk_pixmap_unref(pbi->icon_pixmap);
- gdk_pixmap_unref(pbi->icon_mask);
- gdk_window_unref(pbi->icon_window);
- }
- else
- pbi = g_new(IconInfo, 1);
-
- {
- GdkWindowAttr wa;
- wa.visual = gdk_rgb_get_visual();
- wa.colormap = gdk_rgb_get_cmap();
- pbi->icon_window = gdk_window_new(GDK_ROOT_PARENT(), &wa, GDK_WA_VISUAL|GDK_WA_COLORMAP);
- }
- gdk_pixbuf_render_pixmap_and_mask(pixbuf, &pbi->icon_pixmap, &pbi->icon_mask, 128);
-
- if(!skip_connect)
- {
- gtk_object_set_data(GTK_OBJECT(window), "WM_HINTS.icon_info", pbi);
- gtk_signal_connect_after(GTK_OBJECT(window), "realize", GTK_SIGNAL_FUNC(gnome_window_realized), pbi);
- gtk_signal_connect(GTK_OBJECT(window), "destroy", GTK_SIGNAL_FUNC(gnome_window_destroyed), pbi);
- }
-
- if(GTK_WIDGET_REALIZED(window))
- gnome_window_realized(window, pbi);
-}
-
-void
-gnome_window_set_icon_from_file(GtkWindow *window, const char *filename, gboolean overwrite)
-{
- GdkPixbuf *pb;
- GError *error;
-
- error = NULL;
- pb = gdk_pixbuf_new_from_file(filename, &error);
- if (error != NULL) {
- g_warning (error->message);
- g_error_free (error);
- }
- if(!pb)
- {
- error = NULL;
- filename = gnome_program_locate_file (gnome_program_get (),
- GNOME_FILE_DOMAIN_PIXMAP,
- filename, TRUE, NULL);
-
- pb = gdk_pixbuf_new_from_file(filename, &error);
- if (error != NULL) {
- g_warning (error->message);
- g_error_free (error);
- }
- g_free((gpointer)filename);
- }
- if(!pb)
- return;
-
- gnome_window_set_icon(window, pb, overwrite);
- gdk_pixbuf_unref(pb);
-}
+#endif /* GNOME_DISABLE_DEPRECATED_SOURCE */
diff --git a/libgnomeui/gnome-app-util.h b/libgnomeui/gnome-app-util.h
index fddabe2..4cc6225 100644
--- a/libgnomeui/gnome-app-util.h
+++ b/libgnomeui/gnome-app-util.h
@@ -29,6 +29,7 @@
Convenience UI functions for use with GnomeApp
****/
+#ifndef GNOME_DISABLE_DEPRECATED_SOURCE
#include <gdk-pixbuf/gdk-pixbuf.h>
#include "gnome-app.h"
@@ -139,9 +140,8 @@ gnome_app_set_progress (GnomeAppProgressKey key, gdouble percent);
void
gnome_app_progress_done (GnomeAppProgressKey key);
-void gnome_window_set_icon(GtkWindow *window, GdkPixbuf *pixbuf, gboolean overwrite);
-void gnome_window_set_icon_from_file(GtkWindow *window, const char *filename, gboolean overwrite);
-
G_END_DECLS
+#endif /* GNOME_DISABLE_DEPRECATED_SOURCE */
+
#endif
diff --git a/libgnomeui/gnome-app.h b/libgnomeui/gnome-app.h
index 2e56638..68b3443 100644
--- a/libgnomeui/gnome-app.h
+++ b/libgnomeui/gnome-app.h
@@ -41,8 +41,7 @@
#include <gtk/gtktoolbar.h>
#include <gtk/gtkwindow.h>
-
-#include "gnome-dock.h"
+#include <bonobo/bonobo-dock.h>
G_BEGIN_DECLS
@@ -88,7 +87,7 @@ struct _GnomeApp {
GtkWidget *contents;
/* Dock layout. */
- GnomeDockLayout *layout;
+ BonoboDockLayout *layout;
/* Main accelerator group for this window (hotkeys live here). */
GtkAccelGroup *accel_group;
@@ -139,8 +138,8 @@ void gnome_app_set_contents (GnomeApp *app, GtkWidget *contents);
void gnome_app_add_toolbar (GnomeApp *app,
GtkToolbar *toolbar,
const gchar *name,
- GnomeDockItemBehavior behavior,
- GnomeDockPlacement placement,
+ BonoboDockItemBehavior behavior,
+ BonoboDockPlacement placement,
gint band_num,
gint band_position,
gint offset);
@@ -148,24 +147,24 @@ void gnome_app_add_toolbar (GnomeApp *app,
GtkWidget *gnome_app_add_docked (GnomeApp *app,
GtkWidget *widget,
const gchar *name,
- GnomeDockItemBehavior behavior,
- GnomeDockPlacement placement,
+ BonoboDockItemBehavior behavior,
+ BonoboDockPlacement placement,
gint band_num,
gint band_position,
gint offset);
void gnome_app_add_dock_item (GnomeApp *app,
- GnomeDockItem *item,
- GnomeDockPlacement placement,
+ BonoboDockItem *item,
+ BonoboDockPlacement placement,
gint band_num,
gint band_position,
gint offset);
void gnome_app_enable_layout_config (GnomeApp *app, gboolean enable);
-GnomeDock *gnome_app_get_dock (GnomeApp *app);
+BonoboDock *gnome_app_get_dock (GnomeApp *app);
-GnomeDockItem *gnome_app_get_dock_item_by_name (GnomeApp *app,
+BonoboDockItem *gnome_app_get_dock_item_by_name (GnomeApp *app,
const gchar *name);
G_END_DECLS
diff --git a/libgnomeui/libgnomeui.h b/libgnomeui/libgnomeui.h
index 3e7d08e..0e3bc26 100644
--- a/libgnomeui/libgnomeui.h
+++ b/libgnomeui/libgnomeui.h
@@ -29,6 +29,11 @@
#include <libgnomeui/gnome-uidefs.h>
+
+#include <libgnomeui/gnome-app.h>
+#include <libgnomeui/gnome-app-helper.h>
+#include <libgnomeui/gnome-app-util.h>
+#include <libgnomeui/gnome-appbar.h>
#include <libgnomecanvas/gnome-canvas.h>
#include <libgnomecanvas/gnome-canvas-pixbuf.h>
#include <libgnomecanvas/gnome-canvas-line.h>
@@ -39,6 +44,7 @@
#include <libgnomecanvas/gnome-canvas-widget.h>
#include <libgnomeui/gnome-color-picker.h>
#include <libgnomeui/gnome-entry.h>
+#include <libgnomeui/gnome-file-entry.h>
#include <libgnomeui/gnome-image-entry.h>
#include <libgnomeui/gnome-image-selector.h>
@@ -53,10 +59,13 @@
#include <libgnomeui/gnometypebuiltins.h>
#include <libgnomeui/gnome-winhints.h>
#include <libgnomeui/gnome-href.h>
+#include <libgnomeui/gnome-dialog.h>
+#include <libgnomeui/gnome-dialog-util.h>
#include <libgnomeui/gnome-druid.h>
#include <libgnomeui/gnome-druid-page.h>
#include <libgnomeui/gnome-druid-page-edge.h>
#include <libgnomeui/gnome-druid-page-standard.h>
+#include <libgnomeui/gnome-messagebox.h>
#include <libgnomeui/gnome-vfs-util.h>
#ifdef COMPAT_1_0
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/libgnomeui/gnome-app.c b/libgnomeui/gnome-app.c
index 12243cc..15ce4b4 100644
--- a/libgnomeui/gnome-app.c
+++ b/libgnomeui/gnome-app.c
@@ -34,7 +34,7 @@
*
* Toolbar separators and configurable relief by Andrew Veliath.
*
- * Modified by Ettore Perazzoli to support GnomeDock.
+ * Modified by Ettore Perazzoli to support BonoboDock.
*
*/
@@ -47,14 +47,14 @@
/* Must be before all other gnome includes!! */
#include "gnome-i18nP.h"
+
#include <libgnome/gnome-program.h>
#include <libgnome/gnome-util.h>
#include <libgnome/gnome-config.h>
#include <libgnome/gnome-preferences.h>
+#include <bonobo/bonobo-dock.h>
#include "gnome-app-helper.h"
#include "gnome-uidefs.h"
-#include "gnome-dock.h"
-#include "gnome-init.h"
#include "gnome-window.h"
#include "gnome-app.h"
@@ -86,7 +86,7 @@ static void gnome_app_set_property (GObject *object,
static gchar *read_layout_config (GnomeApp *app);
static void write_layout_config (GnomeApp *app,
- GnomeDockLayout *layout);
+ BonoboDockLayout *layout);
static void layout_changed (GtkWidget *widget,
gpointer data);
@@ -107,11 +107,11 @@ read_layout_config (GnomeApp *app)
}
static void
-write_layout_config (GnomeApp *app, GnomeDockLayout *layout)
+write_layout_config (GnomeApp *app, BonoboDockLayout *layout)
{
gchar *s;
- s = gnome_dock_layout_create_string (layout);
+ s = bonobo_dock_layout_create_string (layout);
gnome_config_push_prefix (app->prefix);
gnome_config_set_string (LAYOUT_CONFIG_PATH, s);
gnome_config_pop_prefix ();
@@ -190,8 +190,10 @@ gnome_app_get_property (GObject *object,
static void
gnome_app_init (GnomeApp *app)
{
+ /* FIXME!!!!!!!
const char *str = NULL;
GValue value = { 0, };
+ */
app->_priv = NULL;
/* XXX: when there is some private stuff enable this
@@ -207,7 +209,7 @@ gnome_app_init (GnomeApp *app)
app->vbox = gtk_vbox_new (FALSE, 0);
gtk_container_add (GTK_CONTAINER (app), app->vbox);
- app->dock = gnome_dock_new ();
+ app->dock = bonobo_dock_new ();
gtk_box_pack_start (GTK_BOX (app->vbox), app->dock,
TRUE, TRUE, 0);
@@ -216,9 +218,11 @@ gnome_app_init (GnomeApp *app)
GTK_SIGNAL_FUNC (layout_changed),
(gpointer) app);
- app->layout = gnome_dock_layout_new ();
+ app->layout = bonobo_dock_layout_new ();
app->enable_layout_config = TRUE;
+
+ /* FIXME!!!!!!!
g_value_init (&value, G_TYPE_STRING);
g_object_get_property (G_OBJECT (gnome_program_get ()),
LIBGNOMEUI_PARAM_DEFAULT_ICON, &value);
@@ -226,6 +230,7 @@ gnome_app_init (GnomeApp *app)
if (str != NULL)
gnome_window_set_icon_from_file (GTK_WINDOW (app), str, FALSE);
g_value_unset (&value);
+ */
}
static void
@@ -242,11 +247,11 @@ gnome_app_show (GtkWidget *widget)
/* Override the layout with the user's saved
configuration. */
s = read_layout_config (app);
- gnome_dock_layout_parse_string (app->layout, s);
+ bonobo_dock_layout_parse_string (app->layout, s);
g_free (s);
}
- gnome_dock_add_from_layout (GNOME_DOCK (app->dock),
+ bonobo_dock_add_from_layout (BONOBO_DOCK (app->dock),
app->layout);
if (app->enable_layout_config)
@@ -268,14 +273,14 @@ layout_changed (GtkWidget *w, gpointer data)
GnomeApp *app;
g_return_if_fail (GNOME_IS_APP (data));
- g_return_if_fail (GNOME_IS_DOCK (w));
+ g_return_if_fail (BONOBO_IS_DOCK (w));
app = GNOME_APP (data);
if (app->enable_layout_config) {
- GnomeDockLayout *layout;
+ BonoboDockLayout *layout;
- layout = gnome_dock_get_layout (GNOME_DOCK (app->dock));
+ layout = bonobo_dock_get_layout (BONOBO_DOCK (app->dock));
write_layout_config (app, layout);
gtk_object_unref (GTK_OBJECT (layout));
}
@@ -431,10 +436,10 @@ gnome_app_set_contents (GnomeApp *app, GtkWidget *contents)
g_return_if_fail (contents != NULL);
g_return_if_fail (GTK_IS_WIDGET (contents));
- gnome_dock_set_client_area (GNOME_DOCK (app->dock), contents);
+ bonobo_dock_set_client_area (BONOBO_DOCK (app->dock), contents);
/* Re-fetch it in case it did not change */
- new_contents = gnome_dock_get_client_area (GNOME_DOCK (app->dock));
+ new_contents = bonobo_dock_get_client_area (BONOBO_DOCK (app->dock));
if (new_contents == contents && new_contents != app->contents) {
gtk_widget_show (new_contents);
@@ -460,7 +465,7 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
{
GtkWidget *dock_item;
GtkAccelGroup *ag;
- GnomeDockItemBehavior behavior;
+ BonoboDockItemBehavior behavior;
g_return_if_fail(app != NULL);
g_return_if_fail(GNOME_IS_APP(app));
@@ -468,13 +473,13 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
g_return_if_fail(menubar != NULL);
g_return_if_fail(GTK_IS_MENU_BAR(menubar));
- behavior = (GNOME_DOCK_ITEM_BEH_EXCLUSIVE
- | GNOME_DOCK_ITEM_BEH_NEVER_VERTICAL);
+ behavior = (BONOBO_DOCK_ITEM_BEH_EXCLUSIVE
+ | BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL);
if (!gnome_preferences_get_menubar_detachable())
- behavior |= GNOME_DOCK_ITEM_BEH_LOCKED;
+ behavior |= BONOBO_DOCK_ITEM_BEH_LOCKED;
- dock_item = gnome_dock_item_new (GNOME_APP_MENUBAR_NAME,
+ dock_item = bonobo_dock_item_new (GNOME_APP_MENUBAR_NAME,
behavior);
gtk_container_add (GTK_CONTAINER (dock_item), GTK_WIDGET (menubar));
@@ -498,25 +503,25 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
gtk_container_set_border_width (GTK_CONTAINER (app->menubar),
border_width);
} else
- gnome_dock_item_set_shadow_type (GNOME_DOCK_ITEM (dock_item),
+ bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
GTK_SHADOW_NONE);
if (app->layout != NULL)
- gnome_dock_layout_add_item (app->layout,
- GNOME_DOCK_ITEM (dock_item),
- GNOME_DOCK_TOP,
+ bonobo_dock_layout_add_item (app->layout,
+ BONOBO_DOCK_ITEM (dock_item),
+ BONOBO_DOCK_TOP,
0, 0, 0);
else
- gnome_dock_add_item(GNOME_DOCK(app->dock),
- GNOME_DOCK_ITEM (dock_item),
- GNOME_DOCK_TOP,
+ bonobo_dock_add_item(BONOBO_DOCK(app->dock),
+ BONOBO_DOCK_ITEM (dock_item),
+ BONOBO_DOCK_TOP,
0, 0, 0, TRUE);
gtk_widget_show (GTK_WIDGET (menubar));
gtk_widget_show (GTK_WIDGET (dock_item));
ag = gtk_object_get_data(GTK_OBJECT(app), "GtkAccelGroup");
- if (ag && !g_slist_find(gtk_accel_groups_from_object (GTK_OBJECT (app)), ag))
+ if (ag && !g_slist_find(gtk_accel_groups_from_object (G_OBJECT (app)), ag))
gtk_window_add_accel_group(GTK_WINDOW(app), ag);
}
@@ -593,7 +598,7 @@ gnome_app_set_statusbar_custom (GnomeApp *app,
* @offset: Offset from the previous dock item in the band; if there is
* no previous item, offset from the beginning of the band.
*
* Create a new &GnomeDockItem widget containing @toolbar, and add it
* to @app's dock with the specified layout information. Notice that,
* if automatic layout configuration is enabled, the layout is
* overridden by the saved configuration, if any.
@@ -602,8 +607,8 @@ void
gnome_app_add_toolbar (GnomeApp *app,
GtkToolbar *toolbar,
const gchar *name,
- GnomeDockItemBehavior behavior,
- GnomeDockPlacement placement,
+ BonoboDockItemBehavior behavior,
+ BonoboDockPlacement placement,
gint band_num,
gint band_position,
gint offset)
@@ -616,21 +621,21 @@ gnome_app_add_toolbar (GnomeApp *app,
g_return_if_fail(GNOME_IS_APP(app));
g_return_if_fail(toolbar != NULL);
- dock_item = gnome_dock_item_new (name, behavior);
+ dock_item = bonobo_dock_item_new (name, behavior);
gtk_container_set_border_width (GTK_CONTAINER (toolbar), 1);
gtk_container_add (GTK_CONTAINER (dock_item), GTK_WIDGET (toolbar));
if(app->layout)
- gnome_dock_layout_add_item (app->layout,
- GNOME_DOCK_ITEM (dock_item),
+ bonobo_dock_layout_add_item (app->layout,
+ BONOBO_DOCK_ITEM (dock_item),
placement,
band_num,
band_position,
offset);
else
- gnome_dock_add_item (GNOME_DOCK(app->dock),
- GNOME_DOCK_ITEM (dock_item),
+ bonobo_dock_add_item (BONOBO_DOCK(app->dock),
+ BONOBO_DOCK_ITEM (dock_item),
placement,
band_num,
band_position,
@@ -638,13 +643,13 @@ gnome_app_add_toolbar (GnomeApp *app,
TRUE);
- gnome_app_setup_toolbar(toolbar, GNOME_DOCK_ITEM(dock_item));
+ gnome_app_setup_toolbar(toolbar, BONOBO_DOCK_ITEM(dock_item));
gtk_widget_show (GTK_WIDGET (toolbar));
gtk_widget_show (GTK_WIDGET (dock_item));
ag = gtk_object_get_data(GTK_OBJECT(app), "GtkAccelGroup");
- if (ag && !g_slist_find(gtk_accel_groups_from_object (GTK_OBJECT (app)), ag))
+ if (ag && !g_slist_find(gtk_accel_groups_from_object (G_OBJECT (app)), ag))
gtk_window_add_accel_group(GTK_WINDOW(app), ag);
}
@@ -661,20 +666,20 @@ void
gnome_app_set_toolbar (GnomeApp *app,
GtkToolbar *toolbar)
{
- GnomeDockItemBehavior behavior;
+ BonoboDockItemBehavior behavior;
/* Making dock items containing toolbars use
- `GNOME_DOCK_ITEM_BEH_EXCLUSIVE' is not really a
+ `BONOBO_DOCK_ITEM_BEH_EXCLUSIVE' is not really a
requirement. We only do this for backwards compatibility. */
- behavior = GNOME_DOCK_ITEM_BEH_EXCLUSIVE;
+ behavior = BONOBO_DOCK_ITEM_BEH_EXCLUSIVE;
if (!gnome_preferences_get_toolbar_detachable())
- behavior |= GNOME_DOCK_ITEM_BEH_LOCKED;
+ behavior |= BONOBO_DOCK_ITEM_BEH_LOCKED;
gnome_app_add_toolbar (app, toolbar,
GNOME_APP_TOOLBAR_NAME,
behavior,
- GNOME_DOCK_TOP,
+ BONOBO_DOCK_TOP,
1, 0, 0);
}
@@ -695,22 +700,22 @@ gnome_app_set_toolbar (GnomeApp *app,
**/
void
gnome_app_add_dock_item (GnomeApp *app,
- GnomeDockItem *item,
- GnomeDockPlacement placement,
+ BonoboDockItem *item,
+ BonoboDockPlacement placement,
gint band_num,
gint band_position,
gint offset)
{
if (app->layout)
- gnome_dock_layout_add_item (app->layout,
- GNOME_DOCK_ITEM (item),
+ bonobo_dock_layout_add_item (app->layout,
+ BONOBO_DOCK_ITEM (item),
placement,
band_num,
band_position,
offset);
else
- gnome_dock_add_item (GNOME_DOCK(app->dock),
- GNOME_DOCK_ITEM( item),
+ bonobo_dock_add_item (BONOBO_DOCK(app->dock),
+ BONOBO_DOCK_ITEM( item),
placement,
band_num,
band_position,
@@ -745,17 +750,17 @@ GtkWidget *
gnome_app_add_docked (GnomeApp *app,
GtkWidget *widget,
const gchar *name,
- GnomeDockItemBehavior behavior,
- GnomeDockPlacement placement,
+ BonoboDockItemBehavior behavior,
+ BonoboDockPlacement placement,
gint band_num,
gint band_position,
gint offset)
{
GtkWidget *item;
- item = gnome_dock_item_new (name, behavior);
+ item = bonobo_dock_item_new (name, behavior);
gtk_container_add (GTK_CONTAINER (item), widget);
- gnome_app_add_dock_item (app, GNOME_DOCK_ITEM (item),
+ gnome_app_add_dock_item (app, BONOBO_DOCK_ITEM (item),
placement, band_num, band_position, offset);
return item;
@@ -785,19 +790,19 @@ gnome_app_enable_layout_config (GnomeApp *app, gboolean enable)
*
* Return value: The retrieved dock item.
**/
-GnomeDockItem *
+BonoboDockItem *
gnome_app_get_dock_item_by_name (GnomeApp *app,
const gchar *name)
{
- GnomeDockItem *item;
+ BonoboDockItem *item;
- item = gnome_dock_get_item_by_name (GNOME_DOCK (app->dock), name,
+ item = bonobo_dock_get_item_by_name (BONOBO_DOCK (app->dock), name,
NULL, NULL, NULL, NULL);
if (item == NULL && app->layout != NULL) {
- GnomeDockLayoutItem *i;
+ BonoboDockLayoutItem *i;
- i = gnome_dock_layout_get_item_by_name (app->layout,
+ i = bonobo_dock_layout_get_item_by_name (app->layout,
name);
if (i == NULL)
return NULL;
@@ -812,12 +817,12 @@ gnome_app_get_dock_item_by_name (GnomeApp *app,
* gnome_app_get_dock:
* @app: A &GnomeApp widget
*
* Retrieves the &GnomeDock widget contained in the &GnomeApp.
*
* Returns: The &GnomeDock widget.
**/
-GnomeDock *
+BonoboDock *
gnome_app_get_dock (GnomeApp *app)
{
- return GNOME_DOCK (app->dock);
+ return BONOBO_DOCK (app->dock);
}
@@ -593,7 +598,7 @@ gnome_app_set_statusbar_custom (GnomeApp *app,
* no previous item, offset from the beginning of the band.
*
- * Create a new &GnomeDockItem widget containing @toolbar, and add it
+ * Create a new &BonoboDockItem widget containing @toolbar, and add it
* to @app's dock with the specified layout information. Notice that,
* if automatic layout configuration is enabled, the layout is
@@ -812,12 +817,12 @@ gnome_app_get_dock_item_by_name (GnomeApp *app,
* @app: A &GnomeApp widget
*
- * Retrieves the &GnomeDock widget contained in the &GnomeApp.
+ * Retrieves the &BonoboDock widget contained in the &GnomeApp.
*
@@ -812,12 +817,12 @@ gnome_app_get_dock_item_by_name (GnomeApp *app,
*
- * Returns: The &GnomeDock widget.
+ * Returns: The &BonoboDock widget.
**/